/*------------------------------------------------------------------------
 |  FILE            MD5.java
 |  PART OF         Sverre's Simple JDBC Driver for PostgreSQL
 |  WRITTEN BY      Sverre H. Huseby <shh@thathost.com>
 +----------------------------------------------------------------------*/

package no.shhsoft.postgresql;

import java.io.*;
import java.security.*;

/**
 *
 *
 * @author   Sverre H. Huseby
 *           &lt;<A HREF="mailto:shh@thathost.com">shh@thathost.com</A>&gt;
 * @version  $Id: MD5.java,v 1.1 2002/02/05 22:54:25 sverrehu Exp $
 */
public final class MD5 {
/*-----------------------------------------------------------------------+
|  PRIVATE PART                                                          |
+-----------------------------------------------------------------------*/
    private static MessageDigest md = null;
    private static final String hex = "0123456789abcdef";

    private static final int hexToDec(char hex)
    throws NumberFormatException {
        if (hex >= '0' && hex <= '9')
            return hex - '0';
        hex = Character.toUpperCase(hex);
        if (hex < 'A' || hex > 'F')
            throw new NumberFormatException();
        return 10 + hex - 'A';
    }

    private static final String bytesToString(byte[] b) {
        StringBuffer sb;
        int          len;

        if (b == null)
            return null;
        len = b.length;
        sb = new StringBuffer(2 * b.length);
        for (int q = 0; q < len; q++) {
            sb.append((char) hex.charAt((b[q] >> 4) & 15));
            sb.append((char) hex.charAt(b[q] & 15));
        }
        return sb.toString();
    }

    private static final byte[] stringToBytes(String s)
    throws NumberFormatException {
        byte[] ret;

        if (s == null)
            throw new NumberFormatException();
        s = s.trim();
        if (s.length() != 32)
            throw new NumberFormatException();
        ret = new byte[16];
        for (int q = 0; q < ret.length; q++)
            ret[q] = (byte) ((hexToDec(s.charAt(2 * q)) << 4)
                             | hexToDec(s.charAt(2 * q + 1)));
        return ret;
    }

/*-----------------------------------------------------------------------+
|  PUBLIC INTERFACE                                                      |
+-----------------------------------------------------------------------*/
    public synchronized static final byte[] digest(byte[] buff, int len) {
        byte[] ret = null;

        try {
            if (md == null)
                md = MessageDigest.getInstance("MD5");
            else
                md.reset();

            md.update(buff, 0, len);
            ret = md.digest();
        } catch (NoSuchAlgorithmException e) {
            System.err.println("no message digest algorithm available!");
        }
        return ret;
    }

    public static final byte[] digest(byte[] buff) {
        return digest(buff, buff.length);
    }

    public static final byte[] digest(String s) {
        return digest(s.getBytes());
    }

    public static final String digestToString(byte[] buff, int len) {
        return bytesToString(digest(buff, len));
    }

    public static final String digestToString(byte[] buff) {
        return bytesToString(digest(buff));
    }

    public static final String digestToString(String s) {
        return bytesToString(digest(s));
    }

    /* testing */
//      public static final void main(String[] args) {
//          if (args.length == 1)
//              System.out.println(digestToString(args[0]));
//          else
//              System.err.println("wrong number of arguments");
//      }
}
