/*------------------------------------------------------------------------
 |  FILE            JDBC.java
 |  PART OF
 |  WRITTEN BY      Sverre H. Huseby <shh@thathost.com>
 +----------------------------------------------------------------------*/

package test;

import java.util.*;
import java.io.*;

import java.net.URL;
import java.sql.*;

/**
 *
 *
 * @author    Sverre H. Huseby
 *            &lt;<A HREF="mailto:shh@thathost.com">shh@thathost.com</A>&gt;
 * @version   $Id: Test.java,v 1.4 2002/02/05 23:08:16 sverrehu Exp $
 */
public class Test {
/*-----------------------------------------------------------------------+
 |  PRIVATE PART                                                         |
 +----------------------------------------------------------------------*/
    private Connection con;

    private void connect(String driver, String url) {
        try {
            Class.forName(driver);
        } catch (ClassNotFoundException e) {
            System.err.println("class not found error: " + e.getMessage());
            System.exit(1);
        }
        try {
            con = DriverManager.getConnection(url,
                                              "sverrehu", "3142");
        } catch (SQLException e) {
            System.err.println("connect error: " + e.getMessage());
            e.printStackTrace(System.err);
            System.exit(1);
        }
    }

    private void close() {
        if (con == null)
            return;
        try {
            con.close();
        } catch (SQLException e) {
            System.err.println("close error: " + e.getMessage());
        }
    }

    private String pad(String s, int n) {
        StringBuffer sb;

        sb = new StringBuffer();
        sb.append(s);
        while (sb.length() < n)
            sb.append((char) ' ');
        return sb.toString();
    }

    private void execute(String cmd) {
        int               q, width;
        Statement         stmt;
        ResultSet         rs;
        ResultSetMetaData meta;

        try {
            stmt = con.createStatement();
            rs = stmt.executeQuery(cmd);
            meta = rs.getMetaData();
            for (q = 1; q <= meta.getColumnCount(); q++) {
                width = meta.getColumnDisplaySize(q);
                System.out.print((q > 1 ? " : " : "")
                                 + pad(meta.getColumnName(q), width));
            }
            System.out.println();
            while (rs.next()) {
                for (q = 1; q <= meta.getColumnCount(); q++) {
                    width = meta.getColumnDisplaySize(q);
                    System.out.print((q > 1 ? " : " : "")
                                     + pad(rs.getString(q), width));
                }
                System.out.println();
            }
            rs.close();
            stmt.close();
        } catch (SQLException e) {
            System.err.println("execute error: " + e.getMessage());
            e.printStackTrace(System.err);
        }
    }

    private void commandLoop() {
        String         cmd;
        BufferedReader in;

        in = new BufferedReader(new InputStreamReader(System.in));
        for (;;) {
            System.out.print("JDBC> ");
            try {
                cmd = in.readLine().trim();
            } catch (IOException e) {
                System.err.println(e.getMessage());
                break;
            }
            if (cmd.equalsIgnoreCase("QUIT") || cmd.equalsIgnoreCase("EXIT"))
                break;
            execute(cmd);
        }
    }

/*-----------------------------------------------------------------------+
 |  PUBLIC INTERFACE                                                     |
 +----------------------------------------------------------------------*/
    public static void main(String[] args) {
        Test jdbc;

        if (args.length != 2) {
            System.err.println("arguments: driver url");
            System.exit(1);
        }
        jdbc = new Test();
        jdbc.connect(args[0], args[1]);
        jdbc.commandLoop();
        jdbc.close();
    }
}
